[Libreoffice-commits] .: sc/source

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Thu Aug 30 03:12:59 PDT 2012


 sc/source/core/tool/address.cxx  |    2 +-
 sc/source/core/tool/adiasync.cxx |   14 +++++++-------
 sc/source/core/tool/autoform.cxx |   16 ++++++++--------
 sc/source/core/tool/callform.cxx |    2 +-
 sc/source/core/tool/chartarr.cxx |   20 ++++++++++----------
 sc/source/core/tool/chartlis.cxx |    8 ++++----
 6 files changed, 31 insertions(+), 31 deletions(-)

New commits:
commit e2faffebde9bf2a9b579e7f49cb3d4314808b978
Author: gerhard oettl <gerhard.oettl at ogersoft.at>
Date:   Tue Aug 28 21:28:28 2012 +0200

    fdo#39468: Translated German comments in sc/source/core/tool
    
    Change-Id: I3d27d33a973c601234b5b6e48756df16f567149d
    Reviewed-on: https://gerrit.libreoffice.org/503
    Reviewed-by: Eike Rathke <erack at redhat.com>
    Tested-by: Eike Rathke <erack at redhat.com>

diff --git a/sc/source/core/tool/address.cxx b/sc/source/core/tool/address.cxx
index 1c3c66a..5850e01 100644
--- a/sc/source/core/tool/address.cxx
+++ b/sc/source/core/tool/address.cxx
@@ -1959,7 +1959,7 @@ bool ScAddress::Move( SCsCOL dx, SCsROW dy, SCsTAB dz, ScDocument* pDoc )
 
 bool ScRange::Move( SCsCOL dx, SCsROW dy, SCsTAB dz, ScDocument* pDoc )
 {
-    // Einfahces &, damit beides ausgefuehrt wird!!
+    // single & to process both
     return aStart.Move( dx, dy, dz, pDoc ) & aEnd.Move( dx, dy, dz, pDoc );
 }
 
diff --git a/sc/source/core/tool/autoform.cxx b/sc/source/core/tool/autoform.cxx
index ff2cef6..14be99e 100644
--- a/sc/source/core/tool/autoform.cxx
+++ b/sc/source/core/tool/autoform.cxx
@@ -51,13 +51,13 @@ const sal_Char *linker_dummy = "";
 
 static const sal_Char sAutoTblFmtName[] = "autotbl.fmt";
 
-// bis SO5PF
+// till SO5PF
 const sal_uInt16 AUTOFORMAT_ID_X        = 9501;
 const sal_uInt16 AUTOFORMAT_ID_358      = 9601;
 const sal_uInt16 AUTOFORMAT_DATA_ID_X   = 9502;
 
-// ab SO5
-//! in nachfolgenden Versionen muss der Betrag dieser IDs groesser sein
+// from SO5 on
+// in following versions the value of the IDs must be higher
 const sal_uInt16 AUTOFORMAT_ID_504      = 9801;
 const sal_uInt16 AUTOFORMAT_DATA_ID_504 = 9802;
 
@@ -923,8 +923,8 @@ ScAutoFormat::ScAutoFormat(const ScAutoFormat& r) :
 
 ScAutoFormat::~ScAutoFormat()
 {
-    //  Bei Aenderungen per StarOne wird nicht sofort gespeichert, sondern zuerst nur
-    //  das SaveLater Flag gesetzt. Wenn das Flag noch gesetzt ist, jetzt speichern.
+    //  When modified via StarOne then only the SaveLater flag is set and no saving is done.
+    //  If the flag is set then save now.
 
     if (mbSaveLater)
         Save();
@@ -1039,7 +1039,7 @@ bool ScAutoFormat::Load()
     if (bRet)
     {
         SvStream& rStream = *pStream;
-        // Achtung hier muss ein allgemeiner Header gelesen werden
+        // Attention: A common header has to be read
         sal_uInt16 nVal = 0;
         rStream >> nVal;
         bRet = 0 == rStream.GetError();
@@ -1105,10 +1105,10 @@ bool ScAutoFormat::Save()
         SvStream& rStream = *pStream;
         rStream.SetVersion( fileVersion );
 
-        // Achtung hier muss ein allgemeiner Header gespeichert werden
+        // Attention: A common header has to be saved
         sal_uInt16 nVal = AUTOFORMAT_ID;
         rStream << nVal
-                << (sal_uInt8)2         // Anzahl von Zeichen des Headers incl. diesem
+                << (sal_uInt8)2         // Number of chars of the header including this
                 << (sal_uInt8)::GetSOStoreTextEncoding(
                     osl_getThreadTextEncoding() );
         m_aVersions.Write(rStream, fileVersion);
diff --git a/sc/source/core/tool/callform.cxx b/sc/source/core/tool/callform.cxx
index c9676f2..5d20ad2 100644
--- a/sc/source/core/tool/callform.cxx
+++ b/sc/source/core/tool/callform.cxx
@@ -217,7 +217,7 @@ bool InitExternalFunc(const rtl::OUString& rModuleName)
                 sal_uInt16 nParamCount;
                 ParamType eParamType[MAXFUNCPARAM];
                 ParamType eAsyncType = NONE;
-                // alles initialisieren, falls das AddIn sich schlecht verhaelt
+                // initialize all,  in case the AddIn behaves bad
                 cFuncName[0] = 0;
                 cInternalName[0] = 0;
                 nParamCount = 0;
diff --git a/sc/source/core/tool/chartarr.cxx b/sc/source/core/tool/chartarr.cxx
index 4564a24..1465471 100644
--- a/sc/source/core/tool/chartarr.cxx
+++ b/sc/source/core/tool/chartarr.cxx
@@ -133,7 +133,7 @@ ScMemChart* ScChartArray::CreateMemChartSingle()
     SCSIZE nRow;
 
         //
-        //  wirkliche Groesse (ohne versteckte Zeilen/Spalten)
+        //  real size (without hidden rows/columns)
         //
 
     SCCOL nColAdd = HasRowHeaders() ? 1 : 0;
@@ -148,7 +148,7 @@ ScMemChart* ScChartArray::CreateMemChartSingle()
     ScRangeListRef aRangeListRef(GetRangeList());
     aRangeListRef->front()->GetVars( nCol1, nRow1, nTab1, nCol2, nRow2, nTab2 );
 
-    SCCOL nStrCol = nCol1;      // fuer Beschriftung merken
+    SCCOL nStrCol = nCol1;      // remember for labeling
     SCROW nStrRow = nRow1;
     // Skip hidden columns.
     // TODO: make use of last column value once implemented.
@@ -161,7 +161,7 @@ ScMemChart* ScChartArray::CreateMemChartSingle()
     if (pDocument->RowHidden(nRow1, nTab1, NULL, &nLastRow))
         nRow1 = nLastRow + 1;
 
-    // falls alles hidden ist, bleibt die Beschriftung am Anfang
+    // if everything is hidden then the label remains at the beginning
     if ( nCol1 <= nCol2 )
     {
         nStrCol = nCol1;
@@ -239,7 +239,7 @@ ScMemChart* ScChartArray::CreateMemChartSingle()
             {
                 for (nRow=0; nRow<nRowCount; nRow++)
                 {
-                    double nVal = DBL_MIN;      // Hack fuer Chart, um leere Zellen zu erkennen
+                    double nVal = DBL_MIN;      // Hack for Chart to recognize empty cells
 
                     pDocument->GetCell( aCols[nCol], aRows[nRow], nTab1, pCell );
                     if (pCell)
@@ -369,7 +369,7 @@ ScMemChart* ScChartArray::CreateMemChartMulti()
             {
                 for ( nRow = 0; nRow < nRowCount; nRow++, nIndex++ )
                 {
-                    double nVal = DBL_MIN;      // Hack fuer Chart, um leere Zellen zu erkennen
+                    double nVal = DBL_MIN;      // Hack for Chart to recognize empty cells
                     const ScAddress* pPos = GetPositionMap()->GetPosition( nIndex );
                     if ( pPos )
                     {   // sonst: Luecke
@@ -402,10 +402,10 @@ ScMemChart* ScChartArray::CreateMemChartMulti()
         {
             for ( nRow = 0; nRow < nRowCount; nRow++, nIndex++ )
             {
-                double nVal = DBL_MIN;      // Hack fuer Chart, um leere Zellen zu erkennen
+                double nVal = DBL_MIN;      // Hack for Chart to recognize empty cells
                 const ScAddress* pPos = GetPositionMap()->GetPosition( nIndex );
                 if ( pPos )
-                {   // sonst: Luecke
+                {   // otherwise: Gap
                     ScBaseCell* pCell = pDocument->GetCell( *pPos );
                     if (pCell)
                     {
@@ -431,10 +431,10 @@ ScMemChart* ScChartArray::CreateMemChartMulti()
             }
         }
 
-//2do: Beschriftung bei Luecken
+//2do: Label when gaps
 
         //
-        //  Spalten-Header
+        //  Column header
         //
 
         SCCOL nPosCol = 0;
@@ -463,7 +463,7 @@ ScMemChart* ScChartArray::CreateMemChartMulti()
         }
 
         //
-        //  Zeilen-Header
+        //  Row header
         //
 
         SCROW nPosRow = 0;
diff --git a/sc/source/core/tool/chartlis.cxx b/sc/source/core/tool/chartlis.cxx
index 28968a1..76b4fa2 100644
--- a/sc/source/core/tool/chartlis.cxx
+++ b/sc/source/core/tool/chartlis.cxx
@@ -238,7 +238,7 @@ void ScChartListener::Update()
     if ( pUnoData )
     {
         bDirty = false;
-        //! irgendwann mal erkennen, was sich innerhalb des Charts geaendert hat
+        // recognize some day what has changed inside the Chart
         chart::ChartDataChangeEvent aEvent( pUnoData->GetSource(),
                                         chart::ChartDataChangeType_ALL,
                                         0, 0, 0, 0 );
@@ -652,7 +652,7 @@ void ScChartListenerCollection::UpdateDirtyCharts()
             p->Update();
 
         if (aTimer.IsActive() && !pDoc->IsImportingXML())
-            break;                      // da kam einer dazwischen
+            break;                      // one interfered
     }
 }
 
@@ -748,8 +748,8 @@ void ScChartListenerCollection::UpdateChartsContainingTab( SCTAB nTab )
 
 bool ScChartListenerCollection::operator==( const ScChartListenerCollection& r ) const
 {
-    // hier nicht ScStrCollection::operator==() verwenden, der umstaendlich via
-    // IsEqual und Compare laeuft, stattdessen ScChartListener::operator==()
+    // Do not use ScStrCollection::operator==() here that uses IsEqual und Compare.
+    // Use ScChartListener::operator==() instead.
     if (pDoc != r.pDoc || maListeners.size() != r.maListeners.size())
         return false;
 


More information about the Libreoffice-commits mailing list
diff --git a/sc/source/core/tool/adiasync.cxx b/sc/source/core/tool/adiasync.cxx
index ddfd0ce..ff21c91 100644
--- a/sc/source/core/tool/adiasync.cxx
+++ b/sc/source/core/tool/adiasync.cxx
@@ -76,12 +76,12 @@ ScAddInAsync::ScAddInAsync(sal_uLong nHandleP, FuncData* pFuncData, ScDocument*
 
 ScAddInAsync::~ScAddInAsync()
 {
-    // aSeekObj hat das alles nicht, Handle 0 gibt es sonst nicht
+    // aSeekObj does not have that, handle 0 does not exist otherwise
     if ( nHandle )
     {
         // im dTor wg. theAddInAsyncTbl.DeleteAndDestroy in ScGlobal::Clear
         mpFuncData->Unadvice( (double)nHandle );
-        if ( meType == PTR_STRING && pStr )      // mit Typvergleich wg. Union!
+        if ( meType == PTR_STRING && pStr )      // include type comparison because of union
             delete pStr;
         delete pDocs;
     }
@@ -107,10 +107,10 @@ void ScAddInAsync::CallBack( sal_uLong nHandleP, void* pData )
     ScAddInAsync* p;
     if ( (p = Get( nHandleP )) == NULL )
         return;
-    // keiner mehr dran? Unadvice und weg damit
+
     if ( !p->HasListeners() )
     {
         // nicht im dTor wg. theAddInAsyncTbl.DeleteAndDestroy in ScGlobal::Clear
         theAddInAsyncTbl.erase( p );
         delete p;
         return ;
@@ -148,7 +148,7 @@ void ScAddInAsync::RemoveDocument( ScDocument* pDocumentP )
     if ( !theAddInAsyncTbl.empty() )
     {
         for( ScAddInAsyncs::reverse_iterator iter1 = theAddInAsyncTbl.rbegin(); iter1 != theAddInAsyncTbl.rend(); ++iter1 )
-        {   // rueckwaerts wg. Pointer-Aufrueckerei im Array
+        {   // backwards because of pointer-movement in array
             ScAddInAsync* pAsync = *iter1;
             ScAddInDocs* p = pAsync->pDocs;
             ScAddInDocs::iterator iter2 = p->find( pDocumentP );
@@ -156,7 +156,7 @@ void ScAddInAsync::RemoveDocument( ScDocument* pDocumentP )
             {
                 p->erase( iter2 );
                 if ( p->empty() )
-                {   // dieses AddIn wird nicht mehr benutzt
+                {   // this AddIn is not used anymore
                     theAddInAsyncTbl.erase( --(iter1.base()) );
                     delete pAsync;
                 }
@@ -76,12 +76,12 @@ ScAddInAsync::ScAddInAsync(sal_uLong nHandleP, FuncData* pFuncData, ScDocument*
     if ( nHandle )
     {
-        // im dTor wg. theAddInAsyncTbl.DeleteAndDestroy in ScGlobal::Clear
+        // in dTor because of theAddInAsyncTbl.DeleteAndDestroy in ScGlobal::Clear
         mpFuncData->Unadvice( (double)nHandle );
@@ -107,10 +107,10 @@ void ScAddInAsync::CallBack( sal_uLong nHandleP, void* pData )
     if ( !p->HasListeners() )
     {
-        // nicht im dTor wg. theAddInAsyncTbl.DeleteAndDestroy in ScGlobal::Clear
+        // not in dTor because of theAddInAsyncTbl.DeleteAndDestroy in ScGlobal::Clear
         theAddInAsyncTbl.erase( p );
         delete p;